## FileSystem - Windows
## This file contains some default directories of your system

import os

## Current Directory
CurrentPath = os.getcwd()
## User directory
User = os.environ['USERPROFILE']

## Special Directories
ApplicationData = f'{User}/AppData/Roaming/'
Desktop = f'{User}/Desktop/'
Documents = f'{User}/Documents/'
Downloads = f'{User}/Downloads/'
LocalAppData = f'{User}/AppData/Local/'
Temp = f'{LocalAppData}Temp'
Pictures = f'{User}/Pictures/'
Favorites = f'{User}/Favorites/'



## FileSystem - Android
## This file contains some default directories of your system

import os

## Current Directory
CurrentPath = os.getcwd()

## Access your internal storage
def InternalStorage():
    InternalStorage.Home = '/storage/emulated/0/'
    InternalStorage.Android = '/storage/emulated/0/Android/'
    InternalStorage.Documents = '/storage/emulated/0/Documents/'
    InternalStorage.Downloads = '/storage/emulated/0/Download/'
    InternalStorage.Movies = '/storage/emulated/0/Movies/'
    InternalStorage.Pictures = '/storage/emulated/0/Pictures/'
    
InternalStorage()



## FileSystem - Linux
## This file contains some default directories of your system

import os

## Current Directory
CurrentPath = os.getcwd()
## User directory
User = f'/home/{os.environ["USER"]}/'

## Special Directories
Desktop = f'{User}Desktop/'
Documents = f'{User}Documents/'
Downloads = f'{User}Downloads/'
Music = f'{User}Music/'
